Редактирование интервала матрицы цены (Доступна Суперадминам)

Url: /api/v1/quests/matrix/interval.json

Method: PUT

#### Допустимые параметры:

Параметр | Описание | Тип | Значение по умолчанию
--- | --- | --- | ---
interval_to | Конец код интервала матрицы | int | 0
friday | Цена в пятницу и предпраздничные дни интервала матрицы | int | 0
matrix_id | Уникальный код матрицы | int | 0
weekdays | Цена выходной интервала матрицы | int | 0
interval_id | Уникальный код интервала матрицы | int | 0
holidays | Цена праздники интервала матрицы | int | 0
interval_from | Начало интервала матрицы | int | 0

Добавление интервала матрицы цены (Доступна Суперадминам)

Url: /api/v1/quests/matrix/interval.json

Method: POST

#### Допустимые параметры:

Параметр | Описание | Тип | Значение по умолчанию
--- | --- | --- | ---
interval_to | Конец код интервала матрицы | int | 0
friday | Цена в пятницу и предпраздничные дни интервала матрицы | int | 0
matrix_id | Уникальный код матрицы | int | 0
weekdays | Цена выходной интервала матрицы | int | 0
holidays | Цена праздники интервала матрицы | int | 0
interval_from | Начало интервала матрицы | int | 0

Удаление интервала матрицы цены (Доступна Суперадминам)

Url: /api/v1/quests/matrix/interval.json

Method: DELETE

#### Допустимые параметры:

Параметр | Описание | Тип | Значение по умолчанию
--- | --- | --- | ---
matrix_id | Уникальный код матрицы | int | 0
interval_id | Уникальный код интервала матрицы | int | 0

Получение интервала матрицы цены (Доступна Суперадминам)

Url: /api/v1/quests/matrix/interval.json

Method: GET

#### Допустимые параметры:

Параметр | Описание | Тип | Значение по умолчанию
--- | --- | --- | ---
matrix_id | Уникальный код матрицы | int | 0